.. ISE Ansible Actions documentation main file, created by
   sphinx-quickstart on Tue Dec 12 10:00:39 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ISE Ansible Actions' documentation!
=====================================================

.. toctree::
   :maxdepth: 2
   :caption: User documentation

   plugins/index
   roles/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
